==> gaphor-2.20.0-py3-none-any.whl: gaphor/abc.py <==
from __future__ import annotations

from abc import ABCMeta, abstractmethod
from typing import TYPE_CHECKING, Iterable

if TYPE_CHECKING:
    from gaphor.core.modeling import Element
    from gaphor.diagram.diagramtoolbox import (
        DiagramType,
        ToolboxDefinition,
        ElementCreateInfo,
    )


class Service(metaclass=ABCMeta):
    """Base interface for all services in Gaphor."""

    @abstractmethod
    def shutdown(self) -> None:
        """Shutdown the services, free resources."""


class ActionProvider(metaclass=ABCMeta):
    """An action provider is a special service that provides actions via
    ``@action`` decorators on its methods (see gaphor/action.py)."""

    @abstractmethod
    def __init__(self):
        pass


class ModelingLanguage(metaclass=ABCMeta):
    """A model provider is a special service that provides an entrypoint to a
    model implementation, such as UML, SysML, RAAML."""

    @property
    @abstractmethod
    def name(self) -> str:
        """Human-readable name of the modeling language."""

    @property
    @abstractmethod
    def toolbox_definition(self) -> ToolboxDefinition:
        """Get structure for the toolbox."""

    @property
    @abstractmethod
    def diagram_types(self) -> Iterable[DiagramType]:
        """Iterate diagram types."""

    @property
    @abstractmethod
    def element_types(self) -> Iterable[ElementCreateInfo]:
        """Iterate element types."""

    @abstractmethod
    def lookup_element(self, name: str) -> type[Element] | None:
        """Look up a model element type by (class) name."""

==> gaphor-2.21.0-py3-none-any.whl: gaphor/abc.py <==
from __future__ import annotations

import abc
from typing import TYPE_CHECKING, Iterable

if TYPE_CHECKING:
    from gaphor.core.modeling import Element
    from gaphor.diagram.diagramtoolbox import (
        DiagramType,
        ToolboxDefinition,
        ElementCreateInfo,
    )


class Service(metaclass=abc.ABCMeta):
    """Base interface for all services in Gaphor."""

    @abc.abstractmethod
    def shutdown(self) -> None:
        """Shutdown the services, free resources."""


class ActionProvider(metaclass=abc.ABCMeta):
    """An action provider is a special service that provides actions via
    ``@action`` decorators on its methods (see gaphor/action.py)."""

    @abc.abstractmethod
    def __init__(self):
        pass


class ModelingLanguage(metaclass=abc.ABCMeta):
    """A model provider is a special service that provides an entrypoint to a
    model implementation, such as UML, SysML, RAAML."""

    @property
    @abc.abstractmethod
    def name(self) -> str:
        """Human-readable name of the modeling language."""

    @property
    @abc.abstractmethod
    def toolbox_definition(self) -> ToolboxDefinition:
        """Get structure for the toolbox."""

    @property
    @abc.abstractmethod
    def diagram_types(self) -> Iterable[DiagramType]:
        """Iterate diagram types."""

    @property
    @abc.abstractmethod
    def element_types(self) -> Iterable[ElementCreateInfo]:
        """Iterate element types."""

    @abc.abstractmethod
    def lookup_element(self, name: str) -> type[Element] | None:
        """Look up a model element type by (class) name."""
